==> mountmanager_0.2.4.orig.tar.gz: mountmanager-0.2.4/sources/gui/choosemountpointwidget.h <==
//MountManager - the program for easy mounting of storage devices in Linux
//Copyright (C) 2007-2008 Tikhonov Sergey
//
//This file is part of MountManager Gui
//
//This program is free software; you can redistribute it and/or
//modify it under the terms of the GNU General Public License
//as published by the Free Software Foundation; either version 2
//of the License, or (at your option) any later version.
//
//This program is distributed in the hope that it will be useful,
//but WITHOUT ANY WARRANTY; without even the implied warranty of
//MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//GNU General Public License for more details.
//
//You should have received a copy of the GNU General Public License
//along with this program; if not, write to the Free Software
//Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#ifndef CHOOSEMOUNTPOINTWIDGET_H
#define CHOOSEMOUNTPOINTWIDGET_H

#include <QWidget>
#include <QString>

class QPushButton;
class QLineEdit;

class ChooseMountPointWidget : public QWidget
{
	Q_OBJECT
	public slots:
		void setMountPoint(const QString& mountPoint);
		void chooseMountPoint();
	signals:
		void mountPointValidSignal(bool isValid);
		void mountPointChanged(const QString& );
	private:
		QLineEdit *lineEdit;
		QPushButton *pushButton;

		QString currentMountPoint;
	public:
		ChooseMountPointWidget(QString defaultMountPoint = QString());
		~ChooseMountPointWidget();

		void setReadOnly(bool isReadOnly);
		const QString& mountPoint() const;
		bool isValid() const;
};

#endif

==> mountmanager_0.2.6.orig.tar.gz: mountmanager-0.2.6/sources/gui/choosemountpointwidget.h <==
//MountManager - the program for easy mounting of storage devices in Linux
//Copyright (C) 2007-2008 Tikhonov Sergey
//
//This file is part of MountManager Gui
//
//This program is free software; you can redistribute it and/or
//modify it under the terms of the GNU General Public License
//as published by the Free Software Foundation; either version 2
//of the License, or (at your option) any later version.
//
//This program is distributed in the hope that it will be useful,
//but WITHOUT ANY WARRANTY; without even the implied warranty of
//MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//GNU General Public License for more details.
//
//You should have received a copy of the GNU General Public License
//along with this program; if not, write to the Free Software
//Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#ifndef CHOOSEMOUNTPOINTWIDGET_H
#define CHOOSEMOUNTPOINTWIDGET_H

#include <QWidget>
#include <QString>

class QToolButton;
class QLineEdit;

class ChooseMountPointWidget : public QWidget
{
	Q_OBJECT
	public slots:
		void setMountPoint(const QString& mountPoint);
		void chooseMountPoint();
	signals:
		void mountPointValidSignal(bool isValid);
		void mountPointChanged(const QString& );
	private:
		QLineEdit *lineEdit;
		QToolButton *pushButton;

		QString currentMountPoint;
	public:
		ChooseMountPointWidget(QString defaultMountPoint = QString());
		~ChooseMountPointWidget();

		void setReadOnly(bool isReadOnly);
		const QString& mountPoint() const;
		bool isValid() const;
};

#endif
